@@ -12,7 +12,7 @@ from django.template.defaultfilters import filesizeformat
 from django.utils.translation import ugettext_lazy as _
 
 if get_version()[:3] == '1.3':
-    string_types = str
+    string_types = basestring
 else:
     from django.utils.six import string_types
 
@@ -76,6 +76,19 @@ class CrocoFieldObject(object):
             'uuid': self.attrs['uuid']
         })
 
+    def edit_url(self, user_id, user_name):
+        return reverse('croco_document_edit', kwargs={
+            'uuid': self.attrs['uuid'],
+            'user_id': user_id,
+            'user_name': user_name,
+        })
+
+    def annotations_url(self, user_id):
+        return reverse('croco_document_annotations', kwargs={
+            'uuid': self.attrs['uuid'],
+            'user_id': user_id,
+        })
+
     @property
     def download_document(self):
         return reverse('croco_document_download', kwargs={
